@@ -19,7 +19,7 @@ arma::mat centroids_FKM(arma::mat data, arma::mat U, unsigned int n, unsigned in
   arma::mat out(k,p, arma::fill::zeros);
   arma::mat U_new = trans(U);
 
-  for(int i=0; i<k; i++)
+  for(int i=0; i<(int)k; i++)
   {
 
     out.row(i) = (pow(U_new.row(i),m) * data) / arma::as_scalar(sum(pow(U.col(i),m)));
@@ -40,7 +40,7 @@ arma::mat centroids_FKM_ent(arma::mat data, arma::mat U, unsigned int n, unsigne
   arma::mat out(k,p, arma::fill::zeros);
   arma::mat U_new = trans(U);
 
-  for(int i=0; i<k; i++)
+  for(int i=0; i<(int)k; i++)
   {
 
     out.row(i) = (U_new.row(i) * data) / arma::as_scalar(sum(U.col(i)));
@@ -66,7 +66,7 @@ arma::mat centroids_FKM_pf(arma::mat data, arma::mat U, unsigned int n, unsigned
   double bb1 = (1-b)/(1+b);
   double bb2 = (2*b) / (1+b);
 
-  for(int i=0; i<k; i++)
+  for(int i=0; i<(int)k; i++)
   {
 
     out.row(i) = ((bb1*pow(U_new.row(i),2.0) + bb2 * U_new.row(i)) * data) /  (arma::as_scalar(sum(bb1 * pow(U.col(i),2.0) + bb2 * U.col(i))) + eps);
@@ -95,15 +95,15 @@ List medoids_FKM(arma::mat data, arma::mat U, unsigned int n, unsigned int k, un
   bool value_temp_med = true;
 
 
-  for(int c = 0; c < k; c++)
+  for(int c = 0; c < (int)k; c++)
   {
     min_med_old = min_med_const;
 
-    for(int i=0; i<n; i++)
+    for(int i=0; i<(int)n; i++)
     {
       min_med = 0;
 
-      for(int j=0; j<n; j++)
+      for(int j=0; j<(int)n; j++)
       {
         min_med = min_med + pow(U(j,c),m) * sum(pow(data.row(i) - data.row(j),2.0));
 
